@@ -5,12 +5,6 @@ import joblib
 
 from ._version import __version__ as version_str
 
-from trapeza import account
-from trapeza import arithmetics
-from trapeza import dashboard
-from trapeza import engine
-from trapeza import strategy
-from trapeza import context
 from trapeza import exception
 from trapeza import metric
 from trapeza import utils
