@@ -3,7 +3,7 @@ import operator
 from sklearn.neighbors import KernelDensity
 import numpy as np
 from scipy.integrate import quad
-from trapeza.arithmetics.dtoa import py_dtoa_ryu
+from trapeza.arithmetics import py_dtoa_ryu
 from decimal import Decimal
 
 
